==> zio-aws-ecs_2.13-5.17.128.1-sources.jar: zio/aws/ecs/model/DescribeCapacityProvidersRequest.scala <==
package zio.aws.ecs.model
import java.lang.Integer
import zio.aws.ecs.model.primitives.BoxedInteger
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeCapacityProvidersRequest(
    capacityProviders: Option[Iterable[String]] = None,
    include: Option[Iterable[zio.aws.ecs.model.CapacityProviderField]] = None,
    maxResults: Option[BoxedInteger] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.DescribeCapacityProvidersRequest = {
    import DescribeCapacityProvidersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.DescribeCapacityProvidersRequest
      .builder()
      .optionallyWith(
        capacityProviders.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.capacityProviders)
      .optionallyWith(
        include.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.includeWithStrings)
      .optionallyWith(
        maxResults.map(value => BoxedInteger.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.DescribeCapacityProvidersRequest.ReadOnly =
    zio.aws.ecs.model.DescribeCapacityProvidersRequest.wrap(buildAwsValue())
}
object DescribeCapacityProvidersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.DescribeCapacityProvidersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.DescribeCapacityProvidersRequest =
      zio.aws.ecs.model.DescribeCapacityProvidersRequest(
        capacityProviders.map(value => value),
        include.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def capacityProviders: Option[List[String]]
    def include: Option[List[zio.aws.ecs.model.CapacityProviderField]]
    def maxResults: Option[BoxedInteger]
    def nextToken: Option[String]
    def getCapacityProviders: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("capacityProviders", capacityProviders)
    def getInclude
        : ZIO[Any, AwsError, List[zio.aws.ecs.model.CapacityProviderField]] =
      AwsError.unwrapOptionField("include", include)
    def getMaxResults: ZIO[Any, AwsError, BoxedInteger] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.DescribeCapacityProvidersRequest
  ) extends zio.aws.ecs.model.DescribeCapacityProvidersRequest.ReadOnly {
    override val capacityProviders: Option[List[String]] = scala
      .Option(impl.capacityProviders())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val include
        : Option[List[zio.aws.ecs.model.CapacityProviderField]] = scala
      .Option(impl.include())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ecs.model.CapacityProviderField.wrap(item)
        }.toList
      )
    override val maxResults: Option[BoxedInteger] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.ecs.model.primitives.BoxedInteger(value))
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.DescribeCapacityProvidersRequest
  ): zio.aws.ecs.model.DescribeCapacityProvidersRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ecs_2.13-5.17.155.1-sources.jar: zio/aws/ecs/model/DescribeCapacityProvidersRequest.scala <==
package zio.aws.ecs.model
import java.lang.Integer
import zio.aws.ecs.model.primitives.BoxedInteger
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeCapacityProvidersRequest(
    capacityProviders: Option[Iterable[String]] = None,
    include: Option[Iterable[zio.aws.ecs.model.CapacityProviderField]] = None,
    maxResults: Option[BoxedInteger] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.DescribeCapacityProvidersRequest = {
    import DescribeCapacityProvidersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.DescribeCapacityProvidersRequest
      .builder()
      .optionallyWith(
        capacityProviders.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.capacityProviders)
      .optionallyWith(
        include.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.includeWithStrings)
      .optionallyWith(maxResults.map(value => value: Integer))(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.DescribeCapacityProvidersRequest.ReadOnly =
    zio.aws.ecs.model.DescribeCapacityProvidersRequest.wrap(buildAwsValue())
}
object DescribeCapacityProvidersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.DescribeCapacityProvidersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.DescribeCapacityProvidersRequest =
      zio.aws.ecs.model.DescribeCapacityProvidersRequest(
        capacityProviders.map(value => value),
        include.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def capacityProviders: Option[List[String]]
    def include: Option[List[zio.aws.ecs.model.CapacityProviderField]]
    def maxResults: Option[BoxedInteger]
    def nextToken: Option[String]
    def getCapacityProviders: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("capacityProviders", capacityProviders)
    def getInclude
        : ZIO[Any, AwsError, List[zio.aws.ecs.model.CapacityProviderField]] =
      AwsError.unwrapOptionField("include", include)
    def getMaxResults: ZIO[Any, AwsError, BoxedInteger] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.DescribeCapacityProvidersRequest
  ) extends zio.aws.ecs.model.DescribeCapacityProvidersRequest.ReadOnly {
    override val capacityProviders: Option[List[String]] = scala
      .Option(impl.capacityProviders())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val include
        : Option[List[zio.aws.ecs.model.CapacityProviderField]] = scala
      .Option(impl.include())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ecs.model.CapacityProviderField.wrap(item)
        }.toList
      )
    override val maxResults: Option[BoxedInteger] =
      scala.Option(impl.maxResults()).map(value => value: BoxedInteger)
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.DescribeCapacityProvidersRequest
  ): zio.aws.ecs.model.DescribeCapacityProvidersRequest.ReadOnly = new Wrapper(
    impl
  )
}
